@@ -4,8 +4,8 @@ from kisters.water.rest_client.auth import OpenIDConnect, TemporaryAccess
 
 
 def test_openid_connect():
-    client_id = os.environ["CLIENT_ID"]
-    client_secret = os.environ["CLIENT_SECRET"]
+    client_id = os.environ["HYDRAULIC_NETWORK_CLIENT_ID"]
+    client_secret = os.environ["HYDRAULIC_NETWORK_CLIENT_SECRET"]
     auth = OpenIDConnect(client_id, client_secret)
     access_token = auth.get_access_token()
     assert access_token
@@ -13,8 +13,8 @@ def test_openid_connect():
 
 
 def test_temporary_access():
-    client_id = os.environ["CLIENT_ID"]
-    client_secret = os.environ["CLIENT_SECRET"]
+    client_id = os.environ["HYDRAULIC_NETWORK_CLIENT_ID"]
+    client_secret = os.environ["HYDRAULIC_NETWORK_CLIENT_SECRET"]
     auth = OpenIDConnect(client_id, client_secret)
     access_token = auth.get_access_token()
     assert access_token
