@@ -17,8 +17,10 @@ def json_client():
 
 
 @pytest.fixture
-def msgpack_client():
-    return RESTClient(url=service_url, authentication=auth, msgpack=True)
+def json_client_networks():
+    return RESTClient(
+        url=f"{service_url.rstrip('/')}/rest/networks", authentication=auth
+    )
 
 
 def test_get_str(json_client):
@@ -31,6 +33,6 @@ def test_get_iter(json_client):
     assert isinstance(networks, list)
 
 
-def test_get_msgpack(msgpack_client):
-    networks = msgpack_client.get("rest/networks")
+def test_get(json_client_networks):
+    networks = json_client_networks.get()
     assert isinstance(networks, list)
